Visualization of motions at the Earth's core surface

Surface core flows are inverted directly from geomagnetic data, or from their interpollation through Gauss coefficients, using the radial induction equation at the core mantle boudary (CMB).
We provide here :

Streamfunctions at the CMB, superimposed with scalar fields
(e.g. radial magnetic field, flow norm... under several projections)
Earth's core surface (Aitoff projection)
Orthographic projection
Time-position maps of scalar fields (including geostrophic flow)
(with respect to longitude, latitude or curvilinear coordinates)
Cross-section of secular variation along Φ
Time series of surface core flow spherical harmonics coefficients
Time series of spherical harmonics coefficients
Comparison of core flow predictions observatories
(ground-based observatory series and virtual observatory series)
Comparison with observatories.
Mauersberger-Lowes spectra of the core quantities
for time-average, deviation or at a given date
Spectra of averaged core quantities
Three core flow models are provided and can be downloaded:

- Gillet_gnm_2015
  Quasi-geostrophic motions covering 1940-2010 [Gillet et al, 2015], inverted from the COV-OBS magnetic field model. It consists in an ensemble of 20 realizations, which have been obtained using a weak stochastic temporal constraint and an iterative estimate of the subgrid induction at the core surface, under the frozen flux approximation.
- Barrois_gnm_2017e
  Surface core flows over 1955-2020 obtained under a dynamo spatial norm with a stochastic Kalman filter [Barrois et al, 2017]. These have been inverted from the COV-OBS.x1 magnetic field model. An augmented state approach allows to account for an unmodeled term that includes effects from both subgrid-scale induction and magnetic diffusion [Barrois et al, 2017 + erratum]. Spatial cross-covariances for the core flow, the magnetic field and the unmodeled term are estimated through statistics derived from geodynamo simulations.
- Barrois_VO_2018e
  Surface core flows over 1998-2018 obtained with the same algorithm as Barrois et al, 2017 (+ erratum), but inverted directly from magnetic records above Earth's surface, namely ground-based series and virtual observatory series [Barrois et al, 2018]. Magnetic data have been provided by C. Finlay and M. Hammer from DTU Copenhagen.

In addition, visualisation and download of two archeomagnetic models are provided:

- COV-LAKE and COV-ARCH
  The COV-ARCH and COV-LAKE ensemble of models describe Gauss coefficients for the geomagnetic field over the period spanning 1200 BC to 2000 AD. COV-ARCH is obtained by inverting archeomagnetic and lava data, while COV-LAKE also incorporates sediment series. They are constructed using as a temporal prior cross-covariances corresponding to order 2 Auto-Regressive processes [Hellio and Gillet, 2018].

Magnetic series are also compared with the CHAOS-6 field model [Finlay et al, 2016].

This project is supported by the French National Space Science Agency (CNES).